/*
 *  jDTAUS - DTAUS fileformat.
 *  Copyright (c) 2005 Christian Schulte <cs@schulte.it>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License along
 *  with this program; if not, write to the Free Software Foundation, Inc.,
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
package org.jdtaus.banking.dtaus.swing;

import java.io.File;
import java.util.Locale;
import javax.swing.filechooser.FileFilter;
import org.jdtaus.editor.PhysicalFileFormatter;

/**
 * Adapts {@code PhysicalFileFormatter} instances to {@code FileFilter}s.
 *
 * @author <a href="mailto:cs@schulte.it">Christian Schulte</a>
 * @version $Id: PhysicalFileFormatterFileFilter.java 3324 2007-05-02 01:07:32Z schulte2005 $
 */
class PhysicalFileFormatterFileFilter extends FileFilter
{
    //--PhysicalFileFormatterFileFilter-----------------------------------------

    /** {@code PhysicalFileFormatter} instance adapted to {@code FileFilter}. */
    private PhysicalFileFormatter formatter;

    /**
     * Creates a new {@code PhysicalFileFormatterFileFilter} instance taking
     * the {@code PhysicalFileFormatter} to adapt.
     *
     * @param formatter the {@code PhysicalFileFormatter} to adapt.
     *
     * @throws NullPointerException if {@code formatter} is {@code null}.
     */
    PhysicalFileFormatterFileFilter(final PhysicalFileFormatter formatter)
    {
        if(formatter == null)
        {
            throw new NullPointerException("formatter");
        }

        this.formatter = formatter;
    }

    /**
     * Gets the {@code PhysicalFileFormatter} instance backing the instance.
     *
     * @return the {@code PhysicalFileFormatter} instance backing the instance.
     */
    PhysicalFileFormatter getFormatter()
    {
        return this.formatter;
    }

    //-----------------------------------------PhysicalFileFormatterFileFilter--
    //--FileFilter--------------------------------------------------------------

    public boolean accept(final File f)
    {
        return this.formatter.accept(f);
    }

    public String getDescription()
    {
        return this.formatter.getDescription(Locale.getDefault());
    }

    //--------------------------------------------------------------FileFilter--
}
